from os import getenv

from elasticsearch import Elasticsearch


def get_client():
    return Elasticsearch(getenv("ELASTIC_URL"), timeout=300)


def create_index(index):
    client = get_client()
    client.indices.create(index=index)


def add_document(index, id, doc):
    client = get_client()
    client.index(index=index, id=id, document=doc)


def refresh_index(index):
    client = get_client()
    client.indices.refresh(index=index)


def search(index, query):
    client = get_client()

    resp = client.search(
        index=index,
        size=100,
        query={
            # "query_string": {
            #   "query": "*puan*",
            #   "default_field": "data"
            # }
            "bool": {
                "must": [
                    {"query_string": {"query": query, "default_field": "data"}},
                    # {
                    #     "match": {
                    #         "id": "1",
                    #     }
                    # }
                ]
            }
        },
        highlight={"fields": {"data": {}}},
    )

    hits = []
    for hit in resp["hits"]["hits"]:
        hits.append(
            str(hit["highlight"]) + " ---- " + "%(name)s: %(data)s" % hit["_source"]
        )

    return hits
